Content Creator Goals
=====================

* Make information available to the end users of the site.

- :doc:`CreateNewContent`

  - Add Content form with a slightly more involved
    description of each content type that comes with the CMF.

  - Next form in succession is the "Standard Resource
    Metadata" form which is now a separate use case.  Since
    this is a succession of three steps ("Add Content",
    "Metadata", "Edit") "Define content metadata" use case
    should be merged in with this one.

  - "Edit" form.

- **XXX** "Define content metadata":ChangeMetadata

  This should mainly be pointers back to :doc:`CreateNewContent`.

- :doc:`SubmitContentForPublication`

 - Brief discussion of workflow with references back to
    workflow use cases.

 - Submit for the default workflow

* Ensure that information is up-to-date and accurate.

- :doc:`ViewMyContent`

- :doc:`ChangeContent`

- :doc:`RemoveContent`

- :doc:`UndoChanges`


* Improve content quality over time using end user feedback.

- **XXX** :doc:`EnableDiscussion`

  *Note:  this is not a per-object option in stock CMF.*

* Collaborate with other content creators.

- :doc:`ManageLocalRoles`


* Modify content organization to improve maintainability or navigation.

- :doc:`AddContentFolders`

- :doc:`MoveCopyContent`

- :doc:`RenameContent`
